import { Delegating, Simple, Weak } from '../mapping/authentications';

/**
 * ZetaPush deployables names
 */
var DeployableNames = {
  AUTH_SIMPLE: 'simple',
  AUTH_WEAK: 'weak',
  AUTH_DELEGATING: 'delegating'

  /**
   * Provide abstraction over CometD handshake data structure
   * @access protected
   */
};
var AbstractHandshake = function () {
  /**
   * Create a new handshake manager
   * @param {{authType: string, sandboxId: string, deploymentId: string}} parameters
   */
  function AbstractHandshake(_ref) {
    var authType = _ref.authType,
        sandboxId = _ref.sandboxId,
        deploymentId = _ref.deploymentId;
    babelHelpers.classCallCheck(this, AbstractHandshake);

    /**
     * @access protected
     * @type {string}
     */
    this.authType = authType;
    /**
     * @access protected
     * @type {string}
     */
    this.sandboxId = sandboxId;
    /**
     * @access protected
     * @type {string}
     */
    this.deploymentId = deploymentId;
  }
  /**
   * @param {ClientHelper} client
   * @return {Object}
   */


  babelHelpers.createClass(AbstractHandshake, [{
    key: 'getHandshakeFields',
    value: function getHandshakeFields(client) {
      var authentication = {
        data: this.authData,
        type: client.getSandboxId() + '.' + this.deploymentId + '.' + this.authType,
        version: this.authVersion
      };
      if (client.getResource()) {
        authentication.resource = client.getResource();
      }
      return {
        ext: {
          authentication: authentication
        }
      };
    }
    /**
     * Get auth version
     * @return {string}
     */

  }, {
    key: 'authVersion',
    get: function get() {
      return 'none';
    }
  }]);
  return AbstractHandshake;
}();

/**
 * Provide abstraction over CometD token base handshake data structure
 * @access protected
 * @extends {AbstractHandshake}
 */


var TokenHandshake = function (_AbstractHandshake) {
  babelHelpers.inherits(TokenHandshake, _AbstractHandshake);

  /**
   * @param {{authType: string, deploymentId: string, token: string}} parameters
   */
  function TokenHandshake(_ref2) {
    var authType = _ref2.authType,
        deploymentId = _ref2.deploymentId,
        token = _ref2.token;
    babelHelpers.classCallCheck(this, TokenHandshake);

    /**
     * @access private
     * @type {string}
     */
    var _this = babelHelpers.possibleConstructorReturn(this, (TokenHandshake.__proto__ || Object.getPrototypeOf(TokenHandshake)).call(this, { deploymentId: deploymentId, authType: authType }));

    _this.token = token;
    return _this;
  }
  /**
   * @return {token: string}
   */


  babelHelpers.createClass(TokenHandshake, [{
    key: 'authData',
    get: function get() {
      var token = this.token;

      return {
        token: token
      };
    }
  }]);
  return TokenHandshake;
}(AbstractHandshake);

/**
 * Provide abstraction over CometD credentials based handshake data structure
 * @access protected
 * @extends {AbstractHandshake}
 */


var CredentialsHandshake = function (_AbstractHandshake2) {
  babelHelpers.inherits(CredentialsHandshake, _AbstractHandshake2);

  /**
   * @param {{authType: string, deploymentId: string, login: string, password: string}} parameters
   */
  function CredentialsHandshake(_ref3) {
    var authType = _ref3.authType,
        deploymentId = _ref3.deploymentId,
        login = _ref3.login,
        password = _ref3.password;
    babelHelpers.classCallCheck(this, CredentialsHandshake);

    /**
     * @access private
     * @type {string}
     */
    var _this2 = babelHelpers.possibleConstructorReturn(this, (CredentialsHandshake.__proto__ || Object.getPrototypeOf(CredentialsHandshake)).call(this, { authType: authType, deploymentId: deploymentId }));

    _this2.login = login;
    /**
     * @access private
     * @type {string}
     */
    _this2.password = password;
    return _this2;
  }
  /**
   * Get auth data
   * @return {login: string, password: string}
   */


  babelHelpers.createClass(CredentialsHandshake, [{
    key: 'authData',
    get: function get() {
      var login = this.login,
          password = this.password;

      return {
        login: login, password: password
      };
    }
  }]);
  return CredentialsHandshake;
}(AbstractHandshake);

/**
 * Factory to create handshake
 * @access public
 */


export var Authentication = function () {
  function Authentication() {
    babelHelpers.classCallCheck(this, Authentication);
  }

  babelHelpers.createClass(Authentication, null, [{
    key: 'simple',

    /**
     * @param {{deploymentId: string, login: string, password: string}} parameters
     * @return {CredentialsHandshake}
     * @example
     * // Explicit deploymentId
     * // Authentication provide optional deployment id, according to the following convention `${ServiceType.toLowerCase()_0}`
     * Authentication.delegating({
     *   deploymentId: '<YOUR-SIMPLE-AUTHENTICATION-DEPLOYMENT-ID>',
     *   login: <USER-LOGIN>,
     *   password: '<USER-PASSWORD>'
     * })
     */
    value: function simple(_ref4) {
      var _ref4$deploymentId = _ref4.deploymentId,
          deploymentId = _ref4$deploymentId === undefined ? Simple.DEFAULT_DEPLOYMENT_ID : _ref4$deploymentId,
          login = _ref4.login,
          password = _ref4.password;

      return Authentication.create({
        authType: DeployableNames.AUTH_SIMPLE,
        deploymentId: deploymentId,
        login: login,
        password: password
      });
    }
    /**
     * @param {{deploymentId: string, token: string}} parameters
     * @return {TokenHandshake}
     * @example
     * // Explicit deploymentId
     * // Authentication provide optional deployment id, according to the following convention `${ServiceType.toLowerCase()_0}`
     * Authentication.delegating({
     *   deploymentId: '<YOUR-WEAK-AUTHENTICATION-DEPLOYMENT-ID>',
     *   token: null
     * })
     */

  }, {
    key: 'weak',
    value: function weak(_ref5) {
      var _ref5$deploymentId = _ref5.deploymentId,
          deploymentId = _ref5$deploymentId === undefined ? Weak.DEFAULT_DEPLOYMENT_ID : _ref5$deploymentId,
          token = _ref5.token;

      return Authentication.create({
        authType: DeployableNames.AUTH_WEAK,
        deploymentId: deploymentId,
        login: token,
        password: null
      });
    }
    /**
     * @param {{deploymentId: string, token: string}} parameters
     * @return {TokenHandshake}
     * @example
     * // Explicit deploymentId
     * // Authentication provide optional deployment id, according to the following convention `${ServiceType.toLowerCase()_0}`
     * Authentication.delegating({
     *   deploymentId: '<YOUR-DELEGATING-AUTHENTICATION-DEPLOYMENT-ID>',
     *   token: null
     * })
     */

  }, {
    key: 'delegating',
    value: function delegating(_ref6) {
      var _ref6$deploymentId = _ref6.deploymentId,
          deploymentId = _ref6$deploymentId === undefined ? Delegating.DEFAULT_DEPLOYMENT_ID : _ref6$deploymentId,
          token = _ref6.token;

      return Authentication.create({
        authType: DeployableNames.AUTH_DELEGATING,
        deploymentId: deploymentId,
        login: token,
        password: null
      });
    }
    /**
     * @param {{authType: string, deploymentId: string, login: string, password: string}} parameters
     * @return {TokenHandshake|CredentialsHandshake}
     */

  }, {
    key: 'create',
    value: function create(_ref7) {
      var authType = _ref7.authType,
          deploymentId = _ref7.deploymentId,
          login = _ref7.login,
          password = _ref7.password;

      if (password === null) {
        return new TokenHandshake({ authType: authType, deploymentId: deploymentId, token: login });
      }
      return new CredentialsHandshake({ authType: authType, deploymentId: deploymentId, login: login, password: password });
    }
  }]);
  return Authentication;
}();