import { platformStorage } from './storage';

/**
 * @type {string}
 */
export var ZETAPUSH_SESSION_KEY = 'zetapush.token';

/**
 * Provide abstraction for token persistence
 * @access protected
 */
export var SessionPersistenceStrategy = function () {
  /**
   * @param {{sandboxId: string, storage: DOMStorage}} parameters
   */
  function SessionPersistenceStrategy() {
    var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        sandboxId = _ref.sandboxId,
        _ref$storage = _ref.storage,
        storage = _ref$storage === undefined ? platformStorage : _ref$storage;

    babelHelpers.classCallCheck(this, SessionPersistenceStrategy);

    /**
     * @access private
     * @type {string}
     */
    this.key = ZETAPUSH_SESSION_KEY + '.' + sandboxId;
    /**
     * @access private
     * @type {DOMStorage}
     */
    this.storage = storage;
  }
  /**
   * @return {string} session The stored session
   */


  babelHelpers.createClass(SessionPersistenceStrategy, [{
    key: 'get',
    value: function get() {
      var key = this.key,
          storage = this.storage;

      var json = storage.getItem(key) || '{}';
      var session = {};
      try {
        session = JSON.parse(json);
      } catch (e) {}
      return session;
    }
    /**
     * @param {Object} session The session to store
     */

  }, {
    key: 'set',
    value: function set() {
      var session = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var key = this.key,
          storage = this.storage;

      var json = JSON.stringify(session);
      try {
        storage.setItem(key, json);
      } catch (e) {}
      return session;
    }
  }]);
  return SessionPersistenceStrategy;
}();